@@ -22,6 +22,8 @@
 #' @inheritSection bbotk::OptimizerNLoptr Progress Bars
 #'
 #' @template section_logging
+#' @templateVar optimizer bbotk::OptimizerNLoptr
+#' @template section_optimizer
 #'
 #' @family Tuner
 #' @seealso Package \CRANpkg{mlr3hyperband} for hyperband tuning.
@@ -65,9 +67,9 @@ TunerNLoptr = R6Class("TunerNLoptr",
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       super$initialize(
-        optimizer = OptimizerNLoptr$new()
+        optimizer = OptimizerNLoptr$new(),
+        man = "mlr3tuning::mlr_tuners_nloptr"
       )
-      private$.man = "mlr3tuning::mlr_tuners_nloptr"
     }
   )
 )
