@@ -21,3 +21,8 @@ extract_benchmark_result_learners = function(bmr) {
     bmr$resample_result(n)$learners
   }))
 }
+
+catn = function(..., file = "") {
+  cat(paste0(..., collapse = "\n"), "\n", sep = "", file = file)
+}
+
